Back to list
keith-mvs

cuda-optimization

by keith-mvs

1🍴 0📅 Jan 21, 2026

SKILL.md


name: cuda-optimization description: Optimize CUDA kernels and GPU code for performance. Use when reviewing CUDA code, analyzing performance, or suggesting GPU optimizations. version: 1.0.0

CUDA Optimization Skill

This skill helps optimize CUDA and GPU code for better performance.

When I activate

I automatically activate when you:

  • Review CUDA kernel code (.cu files)
  • Ask about GPU performance or optimization
  • Mention memory coalescing, occupancy, or shared memory
  • Request profiling analysis or bottleneck identification
  • Discuss parallel algorithm efficiency

What I do

Performance Analysis

I analyze CUDA code for:

  • Memory access patterns: Detect uncoalesced accesses, bank conflicts
  • Thread configuration: Evaluate block size, grid size, occupancy
  • Synchronization: Check for unnecessary synchronization points
  • Memory hierarchy: Assess use of shared memory, constant memory, texture memory
  • Warp efficiency: Identify divergence and suboptimal thread utilization

Optimization Suggestions

I provide specific recommendations:

  • Coalescing memory accesses
  • Optimal thread block configurations
  • Shared memory usage patterns
  • Reduction strategies
  • Stream parallelism opportunities
  • Compute vs memory-bound analysis

Code Examples

I show before/after code examples demonstrating:

// ❌ Uncoalesced access
__global__ void slow(float* data, int stride) {
    int idx = threadIdx.x + blockIdx.x * blockDim.x;
    data[idx * stride] = idx;  // Poor pattern
}

// ✅ Coalesced access
__global__ void fast(float* data) {
    int idx = threadIdx.x + blockIdx.x * blockDim.x;
    data[idx] = idx;  // Sequential pattern
}

Tools I use

I leverage:

  • NVIDIA Nsight Copilot (GPT-OSS-120B) for deep CUDA expertise
  • Static code analysis for pattern detection
  • Architecture-specific optimization knowledge (Ampere, Hopper, Ada)
  • Best practices from CUDA Programming Guide

Output format

My suggestions include:

  1. Issue identification with line numbers
  2. Performance impact estimate (low/medium/high)
  3. Specific fix with code example
  4. Architecture notes if relevant

Focus on actionable, measurable improvements.

Score

Total Score

45/100

Based on repository quality metrics

SKILL.md

SKILL.mdファイルが含まれている

+20
LICENSE

ライセンスが設定されている

0/10
説明文

100文字以上の説明がある

0/10
人気

GitHub Stars 100以上

0/15
最近の活動

3ヶ月以内に更新がある

0/10
フォーク

10回以上フォークされている

0/5
Issue管理

オープンIssueが50未満

+5
言語

プログラミング言語が設定されている

0/5
タグ

1つ以上のタグが設定されている

0/5

Reviews

💬

Reviews coming soon